@@ -1,5 +1,5 @@
 #
-# Copyright 2017-2020 European Centre for Medium-Range Weather Forecasts (ECMWF).
+# Copyright 2017-2021 European Centre for Medium-Range Weather Forecasts (ECMWF).
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,21 +17,20 @@
 #   Alessandro Amici - B-Open - https://bopen.eu
 #
 
-import typing as T  # noqa
+import typing as T
 
+PRESSURE_CONVERSION_RULES: T.Dict[T.Tuple[str, ...], float] = {
+    ("Pa", "pascal", "pascals"): 1.0,
+    ("hPa", "hectopascal", "hectopascals", "hpascal", "millibar", "millibars", "mbar"): 100.0,
+    ("decibar", "dbar"): 10000.0,
+    ("bar", "bars"): 100000.0,
+    ("atmosphere", "atmospheres", "atm"): 101325.0,
+}
 
-PRESSURE_CONVERSION_RULES = {
-    ('Pa', 'pascal', 'pascals'): 1.0,
-    ('hPa', 'hectopascal', 'hectopascals', 'hpascal', 'millibar', 'millibars', 'mbar'): 100.0,
-    ('decibar', 'dbar'): 10000.0,
-    ('bar', 'bars'): 100000.0,
-    ('atmosphere', 'atmospheres', 'atm'): 101325.0,
-}  # type: T.Dict[T.Tuple, float]
-
-LENGTH_CONVERSION_RULES = {
-    ('m', 'meter', 'meters'): 1.0,
-    ('cm', 'centimeter', 'centimeters'): 0.01,
-    ('km', 'kilometer', 'kilometers'): 1000.0,
+LENGTH_CONVERSION_RULES: T.Dict[T.Tuple[str, ...], float] = {
+    ("m", "meter", "meters"): 1.0,
+    ("cm", "centimeter", "centimeters"): 0.01,
+    ("km", "kilometer", "kilometers"): 1000.0,
 }
 
 
@@ -40,7 +39,7 @@ class ConversionError(Exception):
 
 
 def simple_conversion_factor(source_units, target_units, rules):
-    # type: (str, str, T.Dict[T.Tuple, float]) -> float
+    # type: (str, str, T.Dict[T.Tuple[str, ...], float]) -> float
     conversion_factor = 1.0
     seen = 0
     for pressure_units, factor in rules.items():
@@ -55,8 +54,7 @@ def simple_conversion_factor(source_units, target_units, rules):
     return conversion_factor
 
 
-def convert_units(data, target_units, source_units):
-    # type: (T.Any, str, str) -> T.Any
+def convert_units(data: T.Any, target_units: str, source_units: str) -> T.Any:
     if target_units == source_units:
         return data
     for rules in [PRESSURE_CONVERSION_RULES, LENGTH_CONVERSION_RULES]:
@@ -67,8 +65,7 @@ def convert_units(data, target_units, source_units):
     raise ConversionError("cannot convert from %r to %r." % (source_units, target_units))
 
 
-def are_convertible(source_units, target_units):
-    # type: (str, str) -> bool
+def are_convertible(source_units: str, target_units: str) -> bool:
     try:
         convert_units(1, source_units, target_units)
     except ConversionError:
